aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/admin.php
diff options
context:
space:
mode:
Diffstat (limited to 'engine/lib/admin.php')
-rw-r--r--engine/lib/admin.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/lib/admin.php b/engine/lib/admin.php
index c680f0a7f..fc3ffd64c 100644
--- a/engine/lib/admin.php
+++ b/engine/lib/admin.php
@@ -22,14 +22,14 @@
* nb. some pages already exist that you can extend), extend the main view to point to it,
* and add controls to your new view.
*
* At the moment this is essentially a wrapper around extend_view.
*
* @param string $new_admin_view The view associated with the control you're adding
* @param string $view The view to extend, by default this is 'admin/main'.
* @param int $priority Optional priority to govern the appearance in the list.
*/
function extend_elgg_admin_page( $new_admin_view, $view = 'admin/main', $priority = 500) {
- return extend_view($view, $new_admin_view, $priority);
+ return elgg_extend_view($view, $new_admin_view, $priority);
}
/**
@@ -22,14 +22,14 @@
* and add controls to your new view.
*
- * At the moment this is essentially a wrapper around extend_view.
+ * At the moment this is essentially a wrapper around elgg_extend_view().
*
* @param string $new_admin_view The view associated with the control you're adding